/*****************************************************************************
 * macosx_popup.cpp
 *****************************************************************************
 * Copyright (C) 2003 the VideoLAN team
 * $Id: d95f3100978cb1613f9f3eed0a20aa967facee1d $
 *
 * Authors: Olivier Teulière <ipkiss@via.ecp.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#ifdef MACOSX_SKINS

#include "macosx_popup.hpp"


MacOSXPopup::MacOSXPopup( intf_thread_t *pIntf )
    : OSPopup( pIntf )
{
    // TODO
}


MacOSXPopup::~MacOSXPopup()
{
    // TODO
}


void MacOSXPopup::show( int xPos, int yPos )
{
    // TODO
}


void MacOSXPopup::hide()
{
    // TODO
}


void MacOSXPopup::addItem( const string &rLabel, int pos )
{
    // TODO
}


void MacOSXPopup::addSeparator( int pos )
{
    // TODO
}


int MacOSXPopup::getPosFromId( int id ) const
{
    // TODO
}


#endif

