/*****************************************************************************
 * VLCProgressPanel.h: A Generic Progress Indicator Panel created for VLC
 *****************************************************************************
 * Copyright (C) 2009-2010 VLC authors and VideoLAN
 * $Id: ec3ee67ecb11eafb5ad892aa970696108be4af38 $
 *
 * Authors: Felix Paul Kühne <fkuehne at videolan dot org>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#import <Cocoa/Cocoa.h>


@interface VLCProgressPanel : NSPanel {
    BOOL _isCancelled;

    IBOutlet NSProgressIndicator * _progressBar;
    IBOutlet NSTextField *_titleField;
    IBOutlet NSTextField *_messageField;
    IBOutlet NSButton *_cancelButton;
    IBOutlet NSImageView *_iconView;
}
- (void)createContentView;

- (void)setDialogTitle:(NSString *)title;
- (void)setDialogMessage:(NSString *)message;
- (void)setCancelButtonLabel:(NSString *)cancelLabel;
- (void)setProgressAsDouble:(double)value;
- (BOOL)isCancelled;

- (IBAction)cancelDialog:(id)sender;

@end
